@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.core;
@@ -76,6 +76,8 @@ import org.slf4j.Logger;
 
 import com.alipay.sofa.rpc.config.ServerConfig;
 
+import jakarta.ws.rs.core.SecurityContext;
+
 public final class GraphManager {
 
     private static final Logger LOG = Log.logger(GraphManager.class);
@@ -158,7 +160,7 @@ public final class GraphManager {
         HugeConfig cloneConfig = cloneGraph.cloneConfig(newName);
         if (StringUtils.isNotEmpty(configText)) {
             PropertiesConfiguration propConfig = ConfigUtil.buildConfig(
-                                                 configText);
+                    configText);
             // Use the passed config to overwrite the old one
             propConfig.getKeys().forEachRemaining(key -> {
                 cloneConfig.setProperty(key, propConfig.getProperty(key));
@@ -259,10 +261,14 @@ public final class GraphManager {
     }
 
     public HugeAuthenticator.User authenticate(Map<String, String> credentials)
-                                               throws AuthenticationException {
+            throws AuthenticationException {
         return this.authenticator().authenticate(credentials);
     }
 
+    public void unauthorize(SecurityContext context) {
+        this.authenticator().unauthorize(context);
+    }
+
     public AuthManager authManager() {
         return this.authenticator().authManager();
     }
@@ -347,7 +353,6 @@ public final class GraphManager {
         return this.authenticator;
     }
 
-
     private void closeTx(final Set<String> graphSourceNamesToCloseTxOn,
                          final Transaction.Status tx) {
         final Set<Graph> graphsToCloseTxOn = new HashSet<>();
@@ -436,20 +441,20 @@ public final class GraphManager {
                         this.authenticator().initAdminUser(token);
                     } catch (Exception e) {
                         throw new BackendException(
-                                  "The backend store of '%s' can't " +
-                                  "initialize admin user", hugegraph.name());
+                                "The backend store of '%s' can't " +
+                                "initialize admin user", hugegraph.name());
                     }
                 }
             }
             BackendStoreInfo info = hugegraph.backendStoreInfo();
             if (!info.exists()) {
                 throw new BackendException(
-                          "The backend store of '%s' has not been initialized",
-                          hugegraph.name());
+                        "The backend store of '%s' has not been initialized",
+                        hugegraph.name());
             }
             if (!info.checkVersion()) {
                 throw new BackendException(
-                          "The backend store version is inconsistent");
+                        "The backend store version is inconsistent");
             }
         }
     }
@@ -521,7 +526,7 @@ public final class GraphManager {
         });
 
         // Add metrics for caches
-        @SuppressWarnings({ "rawtypes", "unchecked" })
+        @SuppressWarnings({"rawtypes", "unchecked"})
         Map<String, Cache<?, ?>> caches = (Map) CacheManager.instance()
                                                             .caches();
         registerCacheMetrics(caches);
