@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.backend.tx;
@@ -29,6 +29,7 @@ import java.util.Set;
 import java.util.function.BiFunction;
 import java.util.function.Consumer;
 import java.util.function.Function;
+import java.util.stream.Collectors;
 
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.hugegraph.HugeException;
@@ -144,19 +145,19 @@ public class GraphTransaction extends IndexableTransaction {
 
         final HugeConfig conf = graph.configuration();
         this.checkCustomVertexExist =
-             conf.get(CoreOptions.VERTEX_CHECK_CUSTOMIZED_ID_EXIST);
+                conf.get(CoreOptions.VERTEX_CHECK_CUSTOMIZED_ID_EXIST);
         this.checkAdjacentVertexExist =
-             conf.get(CoreOptions.VERTEX_ADJACENT_VERTEX_EXIST);
+                conf.get(CoreOptions.VERTEX_ADJACENT_VERTEX_EXIST);
         this.lazyLoadAdjacentVertex =
-             conf.get(CoreOptions.VERTEX_ADJACENT_VERTEX_LAZY);
+                conf.get(CoreOptions.VERTEX_ADJACENT_VERTEX_LAZY);
         this.removeLeftIndexOnOverwrite =
-             conf.get(CoreOptions.VERTEX_REMOVE_LEFT_INDEX);
+                conf.get(CoreOptions.VERTEX_REMOVE_LEFT_INDEX);
         this.commitPartOfAdjacentEdges =
-             conf.get(CoreOptions.VERTEX_PART_EDGE_COMMIT_SIZE);
+                conf.get(CoreOptions.VERTEX_PART_EDGE_COMMIT_SIZE);
         this.ignoreInvalidEntry =
-             conf.get(CoreOptions.QUERY_IGNORE_INVALID_DATA);
+                conf.get(CoreOptions.QUERY_IGNORE_INVALID_DATA);
         this.optimizeAggrByIndex =
-             conf.get(CoreOptions.QUERY_OPTIMIZE_AGGR_BY_INDEX);
+                conf.get(CoreOptions.QUERY_OPTIMIZE_AGGR_BY_INDEX);
         this.batchSize = conf.get(CoreOptions.QUERY_BATCH_SIZE);
         this.pageSize = conf.get(CoreOptions.QUERY_PAGE_SIZE);
 
@@ -180,23 +181,23 @@ public class GraphTransaction extends IndexableTransaction {
     public boolean hasUpdate(HugeType type, Action action) {
         if (type.isVertex()) {
             if (action == Action.DELETE) {
-                if (this.removedVertices.size() > 0) {
+                if (!this.removedVertices.isEmpty()) {
                     return true;
                 }
             } else {
-                if (this.addedVertices.size() > 0 ||
-                    this.updatedVertices.size() > 0) {
+                if (!this.addedVertices.isEmpty() ||
+                    !this.updatedVertices.isEmpty()) {
                     return true;
                 }
             }
         } else if (type.isEdge()) {
             if (action == Action.DELETE) {
-                if (this.removedEdges.size() > 0) {
+                if (!this.removedEdges.isEmpty()) {
                     return true;
                 }
             } else {
-                if (this.addedEdges.size() > 0 ||
-                    this.updatedEdges.size() > 0) {
+                if (!this.addedEdges.isEmpty() ||
+                    !this.updatedEdges.isEmpty()) {
                     return true;
                 }
             }
@@ -300,16 +301,16 @@ public class GraphTransaction extends IndexableTransaction {
     @Override
     protected BackendMutation prepareCommit() {
         // Serialize and add updates into super.deletions
-        if (this.removedVertices.size() > 0 || this.removedEdges.size() > 0) {
+        if (!this.removedVertices.isEmpty() || !this.removedEdges.isEmpty()) {
             this.prepareDeletions(this.removedVertices, this.removedEdges);
         }
 
-        if (this.addedProps.size() > 0 || this.removedProps.size() > 0) {
+        if (!this.addedProps.isEmpty() || !this.removedProps.isEmpty()) {
             this.prepareUpdates(this.addedProps, this.removedProps);
         }
 
         // Serialize and add updates into super.additions
-        if (this.addedVertices.size() > 0 || this.addedEdges.size() > 0) {
+        if (!this.addedVertices.isEmpty() || !this.addedEdges.isEmpty()) {
             this.prepareAdditions(this.addedVertices, this.addedEdges);
         }
 
@@ -444,7 +445,7 @@ public class GraphTransaction extends IndexableTransaction {
                     // Eliminate the property(OUT and IN owner edge)
                     this.doEliminate(this.serializer.writeEdgeProperty(prop));
                     this.doEliminate(this.serializer.writeEdgeProperty(
-                                     prop.switchEdgeOwner()));
+                            prop.switchEdgeOwner()));
                 } else {
                     // Override edge(it will be in addedEdges & updatedEdges)
                     this.addEdge(prop.element());
@@ -473,7 +474,7 @@ public class GraphTransaction extends IndexableTransaction {
                     // Append new property(OUT and IN owner edge)
                     this.doAppend(this.serializer.writeEdgeProperty(prop));
                     this.doAppend(this.serializer.writeEdgeProperty(
-                                  prop.switchEdgeOwner()));
+                            prop.switchEdgeOwner()));
                 } else {
                     // Override edge (it will be in addedEdges & updatedEdges)
                     this.addEdge(prop.element());
@@ -535,7 +536,7 @@ public class GraphTransaction extends IndexableTransaction {
         QueryList<BackendEntry> queries = this.optimizeQueries(query, super::query);
         LOG.debug("{}", queries);
         return queries.empty() ? QueryResults.empty() :
-                                 queries.fetch(this.pageSize);
+               queries.fetch(this.pageSize);
     }
 
     @Override
@@ -690,7 +691,7 @@ public class GraphTransaction extends IndexableTransaction {
         // Override vertices in local `addedVertices`
         this.addedVertices.remove(vertex.id());
         // Force load vertex to ensure all properties are loaded (refer to #2181)
-        if (vertex.schemaLabel().indexLabels().size() > 0) {
+        if (!vertex.schemaLabel().indexLabels().isEmpty()) {
             vertex.forceLoad();
         }
         // Collect the removed vertex
@@ -710,7 +711,7 @@ public class GraphTransaction extends IndexableTransaction {
             for (Edge edge : batchEdges) {
                 vertexIds.add(((HugeEdge) edge).otherVertex().id());
             }
-            assert vertexIds.size() > 0;
+            assert !vertexIds.isEmpty();
             return this.queryAdjacentVertices(vertexIds.toArray());
         });
     }
@@ -776,7 +777,7 @@ public class GraphTransaction extends IndexableTransaction {
             if (vertex == null) {
                 if (checkMustExist) {
                     throw new NotFoundException(
-                              "Vertex '%s' does not exist", id);
+                            "Vertex '%s' does not exist", id);
                 } else if (adjacentVertex) {
                     assert !checkMustExist;
                     // Return undefined if adjacentVertex but !checkMustExist
@@ -1018,9 +1019,7 @@ public class GraphTransaction extends IndexableTransaction {
             if (vertex == null) {
                 return null;
             }
-            if (query.idsSize() == 1) {
-                assert vertex.getEdges().size() == 1;
-            }
+            assert query.idsSize() != 1 || vertex.getEdges().size() == 1;
             /*
              * Copy to avoid ConcurrentModificationException when removing edge
              * because HugeEdge.remove() will update edges in owner vertex
@@ -1218,8 +1217,8 @@ public class GraphTransaction extends IndexableTransaction {
         // Edge direction
         if (direction == Directions.BOTH) {
             query.query(Condition.or(
-                        Condition.eq(HugeKeys.DIRECTION, Directions.OUT),
-                        Condition.eq(HugeKeys.DIRECTION, Directions.IN)));
+                    Condition.eq(HugeKeys.DIRECTION, Directions.OUT),
+                    Condition.eq(HugeKeys.DIRECTION, Directions.IN)));
         } else {
             assert direction == Directions.OUT || direction == Directions.IN;
             query.eq(HugeKeys.DIRECTION, direction);
@@ -1380,8 +1379,8 @@ public class GraphTransaction extends IndexableTransaction {
 
         if (matched != total) {
             throw new HugeException(
-                      "Not supported querying edges by %s, expect %s",
-                      query.conditions(), EdgeId.KEYS[count]);
+                    "Not supported querying edges by %s, expect %s",
+                    query.conditions(), EdgeId.KEYS[count]);
         }
     }
 
@@ -1396,7 +1395,7 @@ public class GraphTransaction extends IndexableTransaction {
 
         boolean supportIn = this.storeFeatures().supportsQueryWithInCondition();
         for (ConditionQuery cq : ConditionQueryFlatten.flatten(
-                                 (ConditionQuery) query, supportIn)) {
+                (ConditionQuery) query, supportIn)) {
             // Optimize by sysprop
             Query q = this.optimizeQuery(cq);
             /*
@@ -1415,8 +1414,7 @@ public class GraphTransaction extends IndexableTransaction {
 
     private Query optimizeQuery(ConditionQuery query) {
         if (query.idsSize() > 0) {
-            throw new HugeException(
-                      "Not supported querying by id and conditions: %s", query);
+            throw new HugeException("Not supported querying by id and conditions: %s", query);
         }
 
         Id label = query.condition(HugeKeys.LABEL);
@@ -1436,11 +1434,10 @@ public class GraphTransaction extends IndexableTransaction {
                     String primaryValues = query.userpropValuesString(keys);
                     LOG.debug("Query vertices by primaryKeys: {}", query);
                     // Convert {vertex-label + primary-key} to vertex-id
-                    Id id = SplicingIdGenerator.splicing(label.asString(),
-                                                         primaryValues);
+                    Id id = SplicingIdGenerator.splicing(label.asString(), primaryValues);
                     /*
-                     * Just query by primary-key(id), ignore other userprop(if
-                     * exists) that it will be filtered by queryVertices(Query)
+                     * Just query by primary-key(id), ignore other user-props(if exists)
+                     * that it will be filtered by queryVertices(Query)
                      */
                     return new IdQuery(query, id);
                 }
@@ -1450,25 +1447,60 @@ public class GraphTransaction extends IndexableTransaction {
         // Optimize edge query
         if (query.resultType().isEdge() && label != null &&
             query.condition(HugeKeys.OWNER_VERTEX) != null &&
-            query.condition(HugeKeys.DIRECTION) != null &&
-            matchEdgeSortKeys(query, false, this.graph())) {
-            // Query edge by sourceVertex + direction + label + sort-values
-            query.optimized(OptimizedType.SORT_KEYS);
-            query = query.copy();
-            // Serialize sort-values
-            List<Id> keys = this.graph().edgeLabel(label).sortKeys();
-            List<Condition> conditions =
-                            GraphIndexTransaction.constructShardConditions(
-                            query, keys, HugeKeys.SORT_VALUES);
-            query.query(conditions);
-            /*
-             * Reset all userprop since transferred to sort-keys, ignore other
-             * userprop(if exists) that it will be filtered by queryEdges(Query)
-             */
-            query.resetUserpropConditions();
+            query.condition(HugeKeys.DIRECTION) != null) {
 
-            LOG.debug("Query edges by sortKeys: {}", query);
-            return query;
+            Directions dir = query.condition(HugeKeys.DIRECTION);
+            EdgeLabel edgeLabel = this.graph().edgeLabel(label);
+
+            if (query.containsRelation(HugeKeys.OWNER_VERTEX, Condition.RelationType.IN)) {
+                // For IN query, filter schema non-adjacent vertices.
+                ArrayList<Id> vertexIdList = query.condition(HugeKeys.OWNER_VERTEX);
+                List<Id> filterVertexList = vertexIdList.stream().filter(vertexId -> {
+                    Vertex vertex = this.graph().vertex(vertexId);
+                    VertexLabel vertexLabel = graph().vertexLabel(vertex.label());
+                    return edgeLabel.linkWithVertexLabel(vertexLabel.id(), dir);
+                }).collect(Collectors.toList());
+
+                if (CollectionUtils.isEmpty(filterVertexList)) {
+                    return new Query(query.resultType());
+                }
+
+                if (vertexIdList.size() != filterVertexList.size()) {
+                    // Modify on the copied relation to avoid affecting other query
+                    Condition.Relation relation = 
+                            query.copyRelationAndUpdateQuery(HugeKeys.OWNER_VERTEX);
+                    relation.value(filterVertexList);
+                }
+            } else if (query.containsRelation(HugeKeys.OWNER_VERTEX, Condition.RelationType.EQ)) {
+                Id vertexId = query.condition(HugeKeys.OWNER_VERTEX);
+                Vertex vertex = QueryResults.one(this.queryVertices(vertexId));
+                if (vertex != null) {
+                    VertexLabel vertexLabel = graph().vertexLabel(vertex.label());
+                    // For EQ query, just skip query storage if adjacent schema doesn't exist
+                    if (!edgeLabel.linkWithVertexLabel(vertexLabel.id(), dir)) {
+                        return new Query(query.resultType());
+                    }
+                }
+            }
+
+            if (matchEdgeSortKeys(query, false, this.graph())) {
+                // Query edge by sourceVertex + direction + label + sort-values
+                query.optimized(OptimizedType.SORT_KEYS);
+                query = query.copy();
+                // Serialize sort-values
+                List<Id> keys = this.graph().edgeLabel(label).sortKeys();
+                List<Condition> conditions = GraphIndexTransaction
+                        .constructShardConditions(query, keys, HugeKeys.SORT_VALUES);
+                query.query(conditions);
+                /*
+                 * Reset all userprop since transferred to sort-keys, ignore other
+                 * userprop(if exists) that it will be filtered by queryEdges(Query)
+                 */
+                query.resetUserpropConditions();
+
+                LOG.debug("Query edges by sortKeys: {}", query);
+                return query;
+            }
         }
 
         /*
@@ -1606,15 +1638,15 @@ public class GraphTransaction extends IndexableTransaction {
         // Check whether passed all non-null property
         @SuppressWarnings("unchecked")
         Collection<Id> nonNullKeys = CollectionUtils.subtract(
-                                     vertexLabel.properties(),
-                                     vertexLabel.nullableKeys());
+                vertexLabel.properties(),
+                vertexLabel.nullableKeys());
         if (!keys.containsAll(nonNullKeys)) {
             @SuppressWarnings("unchecked")
             Collection<Id> missed = CollectionUtils.subtract(nonNullKeys, keys);
             HugeGraph graph = this.graph();
 
             E.checkArgument(false, "All non-null property keys %s of " +
-                            "vertex label '%s' must be set, missed keys %s",
+                                   "vertex label '%s' must be set, missed keys %s",
                             graph.mapPkId2Name(nonNullKeys), vertexLabel.name(),
                             graph.mapPkId2Name(missed));
         }
@@ -1641,11 +1673,11 @@ public class GraphTransaction extends IndexableTransaction {
             HugeVertex newVertex = vertices.get(existedVertex.id());
             if (!existedVertex.label().equals(newVertex.label())) {
                 throw new HugeException(
-                          "The newly added vertex with id:'%s' label:'%s' " +
-                          "is not allowed to insert, because already exist " +
-                          "a vertex with same id and different label:'%s'",
-                          newVertex.id(), newVertex.label(),
-                          existedVertex.label());
+                        "The newly added vertex with id:'%s' label:'%s' " +
+                        "is not allowed to insert, because already exist " +
+                        "a vertex with same id and different label:'%s'",
+                        newVertex.id(), newVertex.label(),
+                        existedVertex.label());
             }
         } finally {
             CloseableIterator.closeIterator(results);
@@ -1709,8 +1741,8 @@ public class GraphTransaction extends IndexableTransaction {
     }
 
     private <T extends HugeElement> Iterator<T> filterUnmatchedRecords(
-                                                Iterator<T> results,
-                                                Query query) {
+            Iterator<T> results,
+            Query query) {
         // Filter unused or incorrect records
         return new FilterIterator<>(results, elem -> {
             // TODO: Left vertex/edge should to be auto removed via async task
@@ -1729,12 +1761,9 @@ public class GraphTransaction extends IndexableTransaction {
                 return false;
             }
             // Process results that query from left index or primary-key
-            if (query.resultType().isVertex() == elem.type().isVertex() &&
-                !rightResultFromIndexQuery(query, elem)) {
-                // Only index query will come here
-                return false;
-            }
-            return true;
+            // Only index query will come here
+            return query.resultType().isVertex() != elem.type().isVertex() ||
+                   rightResultFromIndexQuery(query, elem);
         });
     }
 
@@ -1786,7 +1815,7 @@ public class GraphTransaction extends IndexableTransaction {
     }
 
     private <T extends HugeElement> Iterator<T> filterExpiredResultFromBackend(
-                                    Query query, Iterator<T> results) {
+            Query query, Iterator<T> results) {
         if (this.store().features().supportsTtl() || query.showExpired()) {
             return results;
         }
@@ -1872,12 +1901,12 @@ public class GraphTransaction extends IndexableTransaction {
     }
 
     private <V extends HugeElement> Iterator<V> joinTxRecords(
-                                    Query query,
-                                    Iterator<V> records,
-                                    BiFunction<Query, V, V> matchFunc,
-                                    Map<Id, V> addedTxRecords,
-                                    Map<Id, V> removedTxRecords,
-                                    Map<Id, V> updatedTxRecords) {
+            Query query,
+            Iterator<V> records,
+            BiFunction<Query, V, V> matchFunc,
+            Map<Id, V> addedTxRecords,
+            Map<Id, V> removedTxRecords,
+            Map<Id, V> updatedTxRecords) {
         this.checkOwnerThread();
         // Return the origin results if there is no change in tx
         if (addedTxRecords.isEmpty() &&
@@ -1923,16 +1952,16 @@ public class GraphTransaction extends IndexableTransaction {
     private void checkTxVerticesCapacity() throws LimitExceedException {
         if (this.verticesInTxSize() >= this.verticesCapacity) {
             throw new LimitExceedException(
-                      "Vertices size has reached tx capacity %d",
-                      this.verticesCapacity);
+                    "Vertices size has reached tx capacity %d",
+                    this.verticesCapacity);
         }
     }
 
     private void checkTxEdgesCapacity() throws LimitExceedException {
         if (this.edgesInTxSize() >= this.edgesCapacity) {
             throw new LimitExceedException(
-                      "Edges size has reached tx capacity %d",
-                      this.edgesCapacity);
+                    "Edges size has reached tx capacity %d",
+                    this.edgesCapacity);
         }
     }
 
@@ -2075,7 +2104,7 @@ public class GraphTransaction extends IndexableTransaction {
         HugeType type = label.type() == HugeType.VERTEX_LABEL ?
                         HugeType.VERTEX : HugeType.EDGE;
         Query query = label.enableLabelIndex() ? new ConditionQuery(type) :
-                                                 new Query(type);
+                      new Query(type);
         query.capacity(Query.NO_CAPACITY);
         query.limit(Query.NO_LIMIT);
         if (this.store().features().supportsQueryByPage()) {
