@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.schema.builder;
@@ -26,26 +26,26 @@ import java.util.Map;
 import java.util.Set;
 
 import org.apache.commons.collections.CollectionUtils;
-
+import org.apache.hugegraph.HugeGraph;
 import org.apache.hugegraph.backend.id.Id;
 import org.apache.hugegraph.backend.id.IdGenerator;
 import org.apache.hugegraph.backend.tx.SchemaTransaction;
-import org.apache.hugegraph.schema.PropertyKey;
-import org.apache.hugegraph.schema.Userdata;
-import org.apache.hugegraph.schema.VertexLabel;
-import org.apache.hugegraph.HugeGraph;
 import org.apache.hugegraph.exception.ExistedException;
 import org.apache.hugegraph.exception.NotAllowException;
 import org.apache.hugegraph.exception.NotFoundException;
+import org.apache.hugegraph.schema.PropertyKey;
+import org.apache.hugegraph.schema.Userdata;
+import org.apache.hugegraph.schema.VertexLabel;
 import org.apache.hugegraph.type.HugeType;
 import org.apache.hugegraph.type.define.Action;
 import org.apache.hugegraph.type.define.IdStrategy;
 import org.apache.hugegraph.util.CollectionUtil;
 import org.apache.hugegraph.util.E;
+
 import com.google.common.collect.ImmutableList;
 
 public class VertexLabelBuilder extends AbstractBuilder
-                                implements VertexLabel.Builder {
+        implements VertexLabel.Builder {
 
     private Id id;
     private String name;
@@ -105,7 +105,7 @@ public class VertexLabelBuilder extends AbstractBuilder
         vertexLabel.ttl(this.ttl);
         if (this.ttlStartTime != null) {
             vertexLabel.ttlStartTime(this.graph().propertyKey(
-                                     this.ttlStartTime).id());
+                    this.ttlStartTime).id());
         }
         // Assign properties
         for (String key : this.properties) {
@@ -157,6 +157,7 @@ public class VertexLabelBuilder extends AbstractBuilder
      * Check whether this has same properties with existedVertexLabel.
      * Only properties, primaryKeys, nullableKeys, enableLabelIndex are checked.
      * The id, idStrategy, checkExist, userdata are not checked.
+     *
      * @param existedVertexLabel to be compared with
      * @return true if this has same properties with existedVertexLabel
      */
@@ -416,15 +417,15 @@ public class VertexLabelBuilder extends AbstractBuilder
             case ELIMINATE:
                 if (!this.properties.isEmpty()) {
                     throw new NotAllowException(
-                              "Not support to eliminate properties " +
-                              "for vertex label currently");
+                            "Not support to eliminate properties " +
+                            "for vertex label currently");
                 }
                 break;
             case DELETE:
                 break;
             default:
                 throw new AssertionError(String.format(
-                          "Unknown schema action '%s'", action));
+                        "Unknown schema action '%s'", action));
         }
     }
 
@@ -434,8 +435,8 @@ public class VertexLabelBuilder extends AbstractBuilder
         if (action == Action.ELIMINATE) {
             if (!this.nullableKeys.isEmpty()) {
                 throw new NotAllowException(
-                          "Not support to eliminate nullableKeys " +
-                          "for vertex label currently");
+                        "Not support to eliminate nullableKeys " +
+                        "for vertex label currently");
             }
             return;
         }
@@ -466,7 +467,7 @@ public class VertexLabelBuilder extends AbstractBuilder
 
         if (action == Action.APPEND) {
             Collection<String> newAddedProps = CollectionUtils.subtract(
-                                               appendProps, originProps);
+                    appendProps, originProps);
             E.checkArgument(this.nullableKeys.containsAll(newAddedProps),
                             "The new added properties: %s must be nullable",
                             newAddedProps);
@@ -475,7 +476,7 @@ public class VertexLabelBuilder extends AbstractBuilder
 
     private void checkIdStrategy() {
         IdStrategy strategy = this.idStrategy;
-        boolean hasPrimaryKey = this.primaryKeys.size() > 0;
+        boolean hasPrimaryKey = !this.primaryKeys.isEmpty();
         switch (strategy) {
             case DEFAULT:
                 if (hasPrimaryKey) {
@@ -499,7 +500,7 @@ public class VertexLabelBuilder extends AbstractBuilder
                 break;
             default:
                 throw new AssertionError(String.format(
-                          "Unknown id strategy '%s'", strategy));
+                        "Unknown id strategy '%s'", strategy));
         }
         if (this.idStrategy == IdStrategy.PRIMARY_KEY) {
             this.checkPrimaryKeys();
@@ -531,18 +532,18 @@ public class VertexLabelBuilder extends AbstractBuilder
     private void checkStableVars() {
         if (!this.primaryKeys.isEmpty()) {
             throw new NotAllowException(
-                      "Not allowed to update primary keys " +
-                      "for vertex label '%s'", this.name);
+                    "Not allowed to update primary keys " +
+                    "for vertex label '%s'", this.name);
         }
         if (this.idStrategy != IdStrategy.DEFAULT) {
             throw new NotAllowException(
-                      "Not allowed to update id strategy " +
-                      "for vertex label '%s'", this.name);
+                    "Not allowed to update id strategy " +
+                    "for vertex label '%s'", this.name);
         }
         if (this.enableLabelIndex != null) {
             throw new NotAllowException(
-                      "Not allowed to update enable_label_index " +
-                      "for vertex label '%s'", this.name);
+                    "Not allowed to update enable_label_index " +
+                    "for vertex label '%s'", this.name);
         }
     }
 
@@ -578,8 +579,8 @@ public class VertexLabelBuilder extends AbstractBuilder
                 for (Map.Entry<String, Object> e : this.userdata.entrySet()) {
                     if (e.getValue() == null) {
                         throw new NotAllowException(
-                                  "Not allowed pass null userdata value when " +
-                                  "create or append edge label");
+                                "Not allowed pass null userdata value when " +
+                                "create or append edge label");
                     }
                 }
                 break;
@@ -589,7 +590,7 @@ public class VertexLabelBuilder extends AbstractBuilder
                 break;
             default:
                 throw new AssertionError(String.format(
-                          "Unknown schema action '%s'", action));
+                        "Unknown schema action '%s'", action));
         }
     }
 
