@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.security;
@@ -24,9 +24,9 @@ import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.CopyOnWriteArraySet;
 
+import org.apache.hugegraph.util.Log;
 import org.slf4j.Logger;
 
-import org.apache.hugegraph.util.Log;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
 
@@ -34,10 +34,8 @@ public class HugeSecurityManager extends SecurityManager {
 
     private static final String USER_DIR = System.getProperty("user.dir");
 
-    private static final String USER_DIR_IDE =
-                                USER_DIR.endsWith("hugegraph-dist") ?
-                                USER_DIR.substring(0, USER_DIR.length() - 15) :
-                                null;
+    private static final String USER_DIR_IDE = USER_DIR.endsWith("hugegraph-dist") ?
+                                               USER_DIR.substring(0, USER_DIR.length() - 15) : null;
 
     private static final String GREMLIN_SERVER_WORKER = "gremlin-server-exec";
     private static final String TASK_WORKER = "task-worker";
@@ -45,11 +43,9 @@ public class HugeSecurityManager extends SecurityManager {
             "org.apache.tinkerpop.gremlin.groovy.jsr223.GremlinGroovyScriptEngine"
     );
 
-    // TODO: add "suppressAccessChecks"
+    // TODO: add "suppressAccessChecks" (influence groovy-AST init now)
     private static final Set<String> DENIED_PERMISSIONS = ImmutableSet.of("setSecurityManager");
 
-
-
     private static final Set<String> ACCEPT_CLASS_LOADERS = ImmutableSet.of(
             "groovy.lang.GroovyClassLoader",
             "sun.reflect.DelegatingClassLoader",
@@ -67,9 +63,12 @@ public class HugeSecurityManager extends SecurityManager {
     private static final Set<String> WHITE_SYSTEM_PROPERTIES = ImmutableSet.of(
             "line.separator",
             "file.separator",
-            "java.specification.version", // Sofa
-            "socksProxyHost", // MySQL
-            "file.encoding" // PostgreSQL
+            // Sofa
+            "java.specification.version",
+            // MySQL
+            "socksProxyHost",
+            // PostgreSQL
+            "file.encoding"
     );
 
     private static final Map<String, Set<String>> ASYNC_TASKS = ImmutableMap.of(
@@ -131,36 +130,32 @@ public class HugeSecurityManager extends SecurityManager {
 
     public static void ignoreCheckedClass(String clazz) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to add ignore check via Gremlin");
+            throw newSecurityException("Not allowed to add ignore check via Gremlin");
         }
-
         IGNORE_CHECKED_CLASSES.add(clazz);
     }
 
     @Override
-    public void checkPermission(Permission permission) {
-        if (DENIED_PERMISSIONS.contains(permission.getName()) &&
-            callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to access denied permission via Gremlin");
+    public void checkPermission(Permission perm) {
+        if (DENIED_PERMISSIONS.contains(perm.getName()) && callFromGremlin()) {
+            // TODO: consider ban the Reflection/Runtime/SerializablePermission after
+            //       identifying the "callFromGremlin()" clearly
+            throw newSecurityException("Not allowed to access denied permission via Gremlin: %s",
+                                       perm);
         }
     }
 
     @Override
-    public void checkPermission(Permission permission, Object context) {
-        if (DENIED_PERMISSIONS.contains(permission.getName()) &&
-            callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to access denied permission via Gremlin");
-        }
+    public void checkPermission(Permission perm, Object context) {
+        this.checkPermission(perm);
+        // Ignore the context & enable when needed
+        //super.checkPermission(perm, context);
     }
 
     @Override
     public void checkCreateClassLoader() {
         if (!callFromAcceptClassLoaders() && callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to create class loader via Gremlin");
+            throw newSecurityException("Not allowed to create class loader via Gremlin");
         }
         super.checkCreateClassLoader();
     }
@@ -168,8 +163,7 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkLink(String lib) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to link library via Gremlin");
+            throw newSecurityException("Not allowed to link library via Gremlin");
         }
         super.checkLink(lib);
     }
@@ -180,8 +174,7 @@ public class HugeSecurityManager extends SecurityManager {
             !callFromAsyncTasks() && !callFromEventHubNotify() &&
             !callFromBackendThread() && !callFromBackendHbase() &&
             !callFromRaft() && !callFromSofaRpc() && !callFromIgnoreCheckedClass()) {
-            throw newSecurityException(
-                  "Not allowed to access thread via Gremlin");
+            throw newSecurityException("Not allowed to access thread via Gremlin");
         }
         super.checkAccess(thread);
     }
@@ -193,8 +186,7 @@ public class HugeSecurityManager extends SecurityManager {
             !callFromBackendThread() && !callFromBackendHbase() &&
             !callFromRaft() && !callFromSofaRpc() &&
             !callFromIgnoreCheckedClass()) {
-            throw newSecurityException(
-                  "Not allowed to access thread group via Gremlin");
+            throw newSecurityException("Not allowed to access thread group via Gremlin");
         }
         super.checkAccess(threadGroup);
     }
@@ -202,8 +194,7 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkExit(int status) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to call System.exit() via Gremlin");
+            throw newSecurityException("Not allowed to call System.exit() via Gremlin");
         }
         super.checkExit(status);
     }
@@ -211,16 +202,15 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkExec(String cmd) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to execute command via Gremlin");
+            throw newSecurityException("Not allowed to execute command via Gremlin");
         }
         super.checkExec(cmd);
     }
 
     @Override
     public void checkRead(FileDescriptor fd) {
-        if (callFromGremlin() && !callFromBackendSocket() &&
-            !callFromRaft() && !callFromSofaRpc()) {
+        if (callFromGremlin() && !callFromBackendSocket() && !callFromRaft() &&
+            !callFromSofaRpc()) {
             throw newSecurityException("Not allowed to read fd via Gremlin");
         }
         super.checkRead(fd);
@@ -230,10 +220,8 @@ public class HugeSecurityManager extends SecurityManager {
     public void checkRead(String file) {
         if (callFromGremlin() && !callFromCaffeine() &&
             !readGroovyInCurrentDir(file) && !callFromBackendHbase() &&
-            !callFromSnapshot() && !callFromRaft() &&
-            !callFromSofaRpc()) {
-            throw newSecurityException(
-                  "Not allowed to read file via Gremlin: %s", file);
+            !callFromSnapshot() && !callFromRaft() && !callFromSofaRpc()) {
+            throw newSecurityException("Not allowed to read file via Gremlin: %s", file);
         }
         super.checkRead(file);
     }
@@ -241,16 +229,15 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkRead(String file, Object context) {
         if (callFromGremlin() && !callFromRaft() && !callFromSofaRpc()) {
-            throw newSecurityException(
-                  "Not allowed to read file via Gremlin: %s", file);
+            throw newSecurityException("Not allowed to read file via Gremlin: %s", file);
         }
         super.checkRead(file, context);
     }
 
     @Override
     public void checkWrite(FileDescriptor fd) {
-        if (callFromGremlin() && !callFromBackendSocket() &&
-            !callFromRaft() && !callFromSofaRpc()) {
+        if (callFromGremlin() && !callFromBackendSocket() && !callFromRaft() &&
+            !callFromSofaRpc()) {
             throw newSecurityException("Not allowed to write fd via Gremlin");
         }
         super.checkWrite(fd);
@@ -258,8 +245,7 @@ public class HugeSecurityManager extends SecurityManager {
 
     @Override
     public void checkWrite(String file) {
-        if (callFromGremlin() && !callFromSnapshot() &&
-            !callFromRaft() && !callFromSofaRpc()) {
+        if (callFromGremlin() && !callFromSnapshot() && !callFromRaft() && !callFromSofaRpc()) {
             throw newSecurityException("Not allowed to write file via Gremlin");
         }
         super.checkWrite(file);
@@ -268,8 +254,7 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkDelete(String file) {
         if (callFromGremlin() && !callFromSnapshot()) {
-            throw newSecurityException(
-                  "Not allowed to delete file via Gremlin");
+            throw newSecurityException("Not allowed to delete file via Gremlin");
         }
         super.checkDelete(file);
     }
@@ -277,8 +262,7 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkListen(int port) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to listen socket via Gremlin");
+            throw newSecurityException("Not allowed to listen socket via Gremlin");
         }
         super.checkListen(port);
     }
@@ -286,8 +270,7 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkAccept(String host, int port) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to accept socket via Gremlin");
+            throw newSecurityException("Not allowed to accept socket via Gremlin");
         }
         super.checkAccept(host, port);
     }
@@ -296,8 +279,7 @@ public class HugeSecurityManager extends SecurityManager {
     public void checkConnect(String host, int port) {
         if (callFromGremlin() && !callFromBackendSocket() &&
             !callFromBackendHbase() && !callFromRaft() && !callFromSofaRpc()) {
-            throw newSecurityException(
-                  "Not allowed to connect socket via Gremlin");
+            throw newSecurityException("Not allowed to connect socket via Gremlin");
         }
         super.checkConnect(host, port);
     }
@@ -305,44 +287,46 @@ public class HugeSecurityManager extends SecurityManager {
     @Override
     public void checkConnect(String host, int port, Object context) {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to connect socket via Gremlin");
+            throw newSecurityException("Not allowed to connect socket via Gremlin");
         }
         super.checkConnect(host, port, context);
     }
 
     @Override
-    public void checkMulticast(InetAddress maddr) {
+    public void checkMulticast(InetAddress addrs) {
         if (callFromGremlin()) {
             throw newSecurityException("Not allowed to multicast via Gremlin");
         }
-        super.checkMulticast(maddr);
+        super.checkMulticast(addrs);
+    }
+
+    public void checkMemberAccess(Class<?> clazz, int which) {
+        if (callFromGremlin()) {
+            throw newSecurityException("Not allowed to access member via Gremlin");
+        }
     }
 
     @Override
     @SuppressWarnings("deprecation")
-    public void checkMulticast(InetAddress maddr, byte ttl) {
+    public void checkMulticast(InetAddress addrs, byte ttl) {
         if (callFromGremlin()) {
             throw newSecurityException("Not allowed to multicast via Gremlin");
         }
-        super.checkMulticast(maddr, ttl);
+        super.checkMulticast(addrs, ttl);
     }
 
     @Override
     public void checkSetFactory() {
         if (callFromGremlin()) {
-            throw newSecurityException(
-                  "Not allowed to set socket factory via Gremlin");
+            throw newSecurityException("Not allowed to set socket factory via Gremlin");
         }
         super.checkSetFactory();
     }
 
     @Override
     public void checkPropertiesAccess() {
-        if (callFromGremlin() && !callFromSofaRpc() &&
-            !callFromNewSecurityException()) {
-            throw newSecurityException(
-                  "Not allowed to access system properties via Gremlin");
+        if (callFromGremlin() && !callFromSofaRpc() && !callFromNewSecurityException()) {
+            throw newSecurityException("Not allowed to access system properties via Gremlin");
         }
         super.checkPropertiesAccess();
     }
@@ -351,10 +335,9 @@ public class HugeSecurityManager extends SecurityManager {
     public void checkPropertyAccess(String key) {
         if (!callFromAcceptClassLoaders() && callFromGremlin() &&
             !WHITE_SYSTEM_PROPERTIES.contains(key) && !callFromBackendHbase() &&
-            !callFromSnapshot() && !callFromRaft() &&
-            !callFromSofaRpc()) {
-            throw newSecurityException(
-                  "Not allowed to access system property(%s) via Gremlin", key);
+            !callFromSnapshot() && !callFromRaft() && !callFromSofaRpc()) {
+            throw newSecurityException("Not allowed to access system property(%s) via Gremlin",
+                                       key);
         }
         super.checkPropertyAccess(key);
     }
@@ -369,6 +352,8 @@ public class HugeSecurityManager extends SecurityManager {
 
     @Override
     public void checkPackageAccess(String pkg) {
+        // TODO: consider ban the "*.reflect" package after identifying "callFromGremlin()" clearly
+        //       maybe better than check in "checkPermission()" (early check & better performance)
         super.checkPackageAccess(pkg);
     }
 
@@ -382,15 +367,13 @@ public class HugeSecurityManager extends SecurityManager {
         super.checkSecurityAccess(target);
     }
 
-    private static SecurityException newSecurityException(String message,
-                                                          Object... args) {
+    private static SecurityException newSecurityException(String message, Object... args) {
         if (args.length > 0) {
             message = String.format(message, args);
         }
         /*
-         * use dynamic logger here because "static final logger" can't be
-         * initialized: the logger is not initialized when HugeSecurityManager
-         * class is loaded
+         * Use dynamic logger here because "static final logger" can't be initialized:
+         * the logger is not initialized when HugeSecurityManager class is loaded
          */
         Logger log = Log.logger(HugeSecurityManager.class);
         log.warn("SecurityException: {}", message);
@@ -398,15 +381,14 @@ public class HugeSecurityManager extends SecurityManager {
     }
 
     private static boolean readGroovyInCurrentDir(String file) {
-        if (file != null && (USER_DIR != null && file.startsWith(USER_DIR) ||
-            USER_DIR_IDE != null && file.startsWith(USER_DIR_IDE)) &&
-            (file.endsWith(".class") || file.endsWith(".groovy"))) {
-            return true;
-        }
-        return false;
+        return file != null && (USER_DIR != null && file.startsWith(USER_DIR) ||
+                                USER_DIR_IDE != null && file.startsWith(USER_DIR_IDE)) &&
+               (file.endsWith(".class") || file.endsWith(".groovy"));
     }
 
+    // TODO: add/use more accurate flag to identify the caller -> callFromUserGremlin()
     private static boolean callFromGremlin() {
+        // Currently, the lifecycle of GremlinExecutor is not clear(too broad)
         return callFromWorkerWithClass(GREMLIN_EXECUTOR_CLASS);
     }
 
@@ -430,7 +412,7 @@ public class HugeSecurityManager extends SecurityManager {
 
     private static boolean callFromEventHubNotify() {
         // Fixed issue #758
-        // notify() will create thread when submit task to executor
+        // notify() will create thread when submit a task to executor
         return callFromMethod("org.apache.hugegraph.event.EventHub", "notify");
     }
 
@@ -503,4 +485,20 @@ public class HugeSecurityManager extends SecurityManager {
         }
         return false;
     }
+
+    private static void filterBasicSensitiveClasses() {
+        // TODO: Conflicts with log4j2, handle it in 1.5.0
+        //Reflection.registerFieldsToFilter(Thread.class, "name");
+        //Reflection.registerMethodsToFilter(Class.class, "forName", "newInstance");
+        //Reflection.registerMethodsToFilter(ClassLoader.class, "loadClass", "newInstance");
+        //Reflection.registerMethodsToFilter(Method.class, "invoke", "setAccessible");
+        //Reflection.registerMethodsToFilter(Field.class, "set", "setAccessible");
+        //Reflection.registerMethodsToFilter(java.lang.reflect.Constructor.class, "newInstance",
+        //                                   "setAccessible");
+        //Reflection.registerMethodsToFilter(Runtime.class, "exec", "getRuntime");
+        //Reflection.registerMethodsToFilter(ProcessBuilder.class, "command", "start",
+        //                                   "startPipeline");
+        //Reflection.registerMethodsToFilter(Reflection.loadClass("java.lang.ProcessImpl"),
+        //                                   "forkAndExec", "setAccessible", "start");
+    }
 }
