@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.structure;
@@ -46,7 +46,6 @@ import org.apache.hugegraph.util.E;
 import org.apache.hugegraph.util.InsertionOrderUtil;
 import org.apache.hugegraph.util.collection.CollectionFactory;
 import org.apache.tinkerpop.gremlin.structure.Element;
-import org.apache.tinkerpop.gremlin.structure.Property;
 import org.apache.tinkerpop.gremlin.structure.T;
 import org.apache.tinkerpop.gremlin.structure.util.ElementHelper;
 import org.eclipse.collections.api.iterator.IntIterator;
@@ -55,7 +54,7 @@ import org.eclipse.collections.api.map.primitive.MutableIntObjectMap;
 public abstract class HugeElement implements Element, GraphType, Idfiable, Comparable<HugeElement> {
 
     private static final MutableIntObjectMap<HugeProperty<?>> EMPTY_MAP =
-                         CollectionFactory.newIntObjectMap();
+            CollectionFactory.newIntObjectMap();
     private static final int MAX_PROPERTIES = BytesBuffer.UINT16_MAX;
 
     private final HugeGraph graph;
@@ -253,7 +252,7 @@ public abstract class HugeElement implements Element, GraphType, Idfiable, Compa
     }
 
     public boolean hasProperties() {
-        return this.properties.size() > 0;
+        return !this.properties.isEmpty();
     }
 
     public int sizeOfProperties() {
@@ -329,7 +328,7 @@ public abstract class HugeElement implements Element, GraphType, Idfiable, Compa
     }
 
     @Watched(prefix = "element")
-    @SuppressWarnings({ "rawtypes", "unchecked" })
+    @SuppressWarnings({"rawtypes", "unchecked"})
     private <V> HugeProperty<V> addProperty(PropertyKey pkey, V value,
                                             Supplier<Collection<V>> supplier) {
         assert pkey.cardinality().multiple();
@@ -372,7 +371,7 @@ public abstract class HugeElement implements Element, GraphType, Idfiable, Compa
             this.properties = EMPTY_MAP;
         } else {
             this.properties = CollectionFactory.newIntObjectMap(
-                              element.properties);
+                    element.properties);
         }
         this.propLoaded = true;
     }
@@ -414,8 +413,9 @@ public abstract class HugeElement implements Element, GraphType, Idfiable, Compa
 
     /**
      * Classify parameter list(pairs) from call request
+     *
      * @param keyValues The property key-value pair of the vertex or edge
-     * @return          Key-value pairs that are classified and processed
+     * @return Key-value pairs that are classified and processed
      */
     @Watched(prefix = "element")
     public static final ElementKeys classifyKeys(Object... keyValues) {
@@ -488,8 +488,8 @@ public abstract class HugeElement implements Element, GraphType, Idfiable, Compa
 
         // Throw if error type
         throw new UnsupportedOperationException(String.format(
-                  "Invalid element id: %s(%s)",
-                  idValue, idValue.getClass().getSimpleName()));
+                "Invalid element id: %s(%s)",
+                idValue, idValue.getClass().getSimpleName()));
     }
 
     @Watched(prefix = "element")
