@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.traversal.algorithm;
@@ -620,18 +620,18 @@ public class HugeTraverser {
         }
     }
 
-    protected Object getVertexLabelId(Object label) {
+    protected Object getVertexLabelIdOrNull(Object label) {
         if (label == null) {
             return null;
         }
-        return SchemaLabel.getLabelId(this.graph, HugeType.VERTEX, label);
+        return SchemaLabel.getVertexLabelId(this.graph, label);
     }
 
-    protected Id getEdgeLabelId(Object label) {
+    protected Id getEdgeLabelIdOrNull(Object label) {
         if (label == null) {
             return null;
         }
-        return SchemaLabel.getLabelId(this.graph, HugeType.EDGE, label);
+        return SchemaLabel.getEdgeLabelId(this.graph, label);
     }
 
     protected void checkVertexExist(Id vertexId, String name) {
@@ -947,6 +947,7 @@ public class HugeTraverser {
     }
 
     public static class EdgeRecord {
+
         private final Map<Long, Edge> edgeMap;
         private final ObjectIntMapping<Id> idMapping;
 
