@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.backend.store.mysql;
@@ -38,6 +38,7 @@ import org.apache.hugegraph.type.HugeType;
 import org.apache.hugegraph.type.define.Directions;
 import org.apache.hugegraph.type.define.HugeKeys;
 import org.apache.hugegraph.util.E;
+
 import com.google.common.collect.ImmutableMap;
 
 public class MysqlTables {
@@ -124,7 +125,7 @@ public class MysqlTables {
                 return rs.getString(formatKey(HugeKeys.VALUE));
             } catch (SQLException e) {
                 throw new BackendException(
-                          "Failed to get stored version with '%s'", e, select);
+                        "Failed to get stored version with '%s'", e, select);
             }
         }
     }
@@ -161,17 +162,17 @@ public class MysqlTables {
                 }
             } catch (SQLException e) {
                 throw new BackendException(
-                          "Failed to get id from counters with type '%s'",
-                          e, type);
+                        "Failed to get id from counters with type '%s'",
+                        e, type);
             }
         }
 
         public void increaseCounter(MysqlSessions.Session session,
                                     HugeType type, long increment) {
             String update = String.format(
-                            "INSERT INTO %s VALUES ('%s', %s) " +
-                            "ON DUPLICATE KEY UPDATE ID = ID + %s;",
-                            this.table(), type.name(), increment, increment);
+                    "INSERT INTO %s VALUES ('%s', %s) " +
+                    "ON DUPLICATE KEY UPDATE ID = ID + %s;",
+                    this.table(), type.name(), increment, increment);
             try {
                 session.execute(update);
             } catch (SQLException e) {
@@ -325,8 +326,8 @@ public class MysqlTables {
 
             this.direction = direction;
             this.delByLabelTemplate = String.format(
-                                      "DELETE FROM %s WHERE %s = ?;",
-                                      this.table(), formatKey(HugeKeys.LABEL));
+                    "DELETE FROM %s WHERE %s = ?;",
+                    this.table(), formatKey(HugeKeys.LABEL));
 
             this.define = new TableDefine(typesMapping);
             this.define.column(HugeKeys.OWNER_VERTEX, SMALL_TEXT);
@@ -350,7 +351,7 @@ public class MysqlTables {
                 String[] idParts = EdgeId.split(id);
                 if (idParts.length == 1) {
                     // Delete edge by label
-                    return Arrays.asList((Object[]) idParts);
+                    return Arrays.asList(idParts);
                 }
                 id = IdUtil.readString(id.asString());
                 edgeId = EdgeId.parse(id.asString());
@@ -373,7 +374,7 @@ public class MysqlTables {
         public void delete(MysqlSessions.Session session, MysqlBackendEntry.Row entry) {
             // Let super class do delete if not deleting edge by label
             List<Object> idParts = this.idColumnValue(entry.id());
-            if (idParts.size() > 1 || entry.columns().size() > 0) {
+            if (idParts.size() > 1 || !entry.columns().isEmpty()) {
                 super.delete(session, entry);
                 return;
             }
@@ -412,7 +413,7 @@ public class MysqlTables {
             long maxSize = BackendEntryIterator.INLINE_BATCH_SIZE;
             if (current != null && current.subRows().size() < maxSize) {
                 Id nextVertexId = IdGenerator.of(
-                                  next.<String>column(HugeKeys.OWNER_VERTEX));
+                        next.<String>column(HugeKeys.OWNER_VERTEX));
                 if (current.id().equals(nextVertexId)) {
                     current.subRow(next.row());
                     return current;
