@@ -1,18 +1,18 @@
 /*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with this
- * work for additional information regarding copyright ownership. The ASF
- * licenses this file to You under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.hugegraph.core;
@@ -22,9 +22,6 @@ import java.util.Iterator;
 import java.util.Random;
 import java.util.concurrent.TimeoutException;
 
-import org.junit.Before;
-import org.junit.Test;
-
 import org.apache.hugegraph.HugeException;
 import org.apache.hugegraph.HugeGraph;
 import org.apache.hugegraph.api.job.GremlinAPI.GremlinRequest;
@@ -41,6 +38,9 @@ import org.apache.hugegraph.task.TaskScheduler;
 import org.apache.hugegraph.task.TaskStatus;
 import org.apache.hugegraph.testutil.Assert;
 import org.apache.hugegraph.testutil.Whitebox;
+import org.junit.Before;
+import org.junit.Test;
+
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 
@@ -249,20 +249,22 @@ public class TaskCoreTest extends BaseCoreTest {
         TaskScheduler scheduler = graph.taskScheduler();
 
         String script = "schema=graph.schema();" +
-                "schema.propertyKey('name').asText().ifNotExist().create();" +
-                "schema.propertyKey('age').asInt().ifNotExist().create();" +
-                "schema.propertyKey('lang').asText().ifNotExist().create();" +
-                "schema.propertyKey('date').asDate().ifNotExist().create();" +
-                "schema.propertyKey('price').asInt().ifNotExist().create();" +
-                "schema.vertexLabel('person1').properties('name','age').ifNotExist().create();" +
-                "schema.vertexLabel('person2').properties('name','age').ifNotExist().create();" +
-                "schema.edgeLabel('knows').sourceLabel('person1').targetLabel('person2')." +
-                "properties('date').ifNotExist().create();" +
-                "for(int i = 0; i < 1000; i++) {" +
-                "  p1=graph.addVertex(T.label,'person1','name','p1-'+i,'age',29);" +
-                "  p2=graph.addVertex(T.label,'person2','name','p2-'+i,'age',27);" +
-                "  p1.addEdge('knows',p2,'date','2016-01-10');" +
-                "}";
+                        "schema.propertyKey('name').asText().ifNotExist().create();" +
+                        "schema.propertyKey('age').asInt().ifNotExist().create();" +
+                        "schema.propertyKey('lang').asText().ifNotExist().create();" +
+                        "schema.propertyKey('date').asDate().ifNotExist().create();" +
+                        "schema.propertyKey('price').asInt().ifNotExist().create();" +
+                        "schema.vertexLabel('person1').properties('name','age').ifNotExist()" +
+                        ".create();" +
+                        "schema.vertexLabel('person2').properties('name','age').ifNotExist()" +
+                        ".create();" +
+                        "schema.edgeLabel('knows').sourceLabel('person1').targetLabel('person2')." +
+                        "properties('date').ifNotExist().create();" +
+                        "for(int i = 0; i < 1000; i++) {" +
+                        "  p1=graph.addVertex(T.label,'person1','name','p1-'+i,'age',29);" +
+                        "  p2=graph.addVertex(T.label,'person2','name','p2-'+i,'age',27);" +
+                        "  p1.addEdge('knows',p2,'date','2016-01-10');" +
+                        "}";
 
         HugeTask<Object> task = runGremlinJob(script);
         task = scheduler.waitUntilTaskCompleted(task.id(), 10);
@@ -308,27 +310,27 @@ public class TaskCoreTest extends BaseCoreTest {
         TaskScheduler scheduler = graph.taskScheduler();
 
         String script = "schema=graph.schema();" +
-                "schema.propertyKey('name').asText().ifNotExist().create();" +
-                "schema.vertexLabel('char').useCustomizeNumberId()" +
-                "      .properties('name').ifNotExist().create();" +
-                "schema.edgeLabel('next').sourceLabel('char').targetLabel('char')" +
-                "      .properties('name').ifNotExist().create();" +
-                "g.addV('char').property(id,1).property('name','A').as('a')" +
-                " .addV('char').property(id,2).property('name','B').as('b')" +
-                " .addV('char').property(id,3).property('name','C').as('c')" +
-                " .addV('char').property(id,4).property('name','D').as('d')" +
-                " .addV('char').property(id,5).property('name','E').as('e')" +
-                " .addV('char').property(id,6).property('name','F').as('f')" +
-                " .addE('next').from('a').to('b').property('name','ab')" +
-                " .addE('next').from('b').to('c').property('name','bc')" +
-                " .addE('next').from('b').to('d').property('name','bd')" +
-                " .addE('next').from('c').to('d').property('name','cd')" +
-                " .addE('next').from('c').to('e').property('name','ce')" +
-                " .addE('next').from('d').to('e').property('name','de')" +
-                " .addE('next').from('e').to('f').property('name','ef')" +
-                " .addE('next').from('f').to('d').property('name','fd')" +
-                " .iterate();" +
-                "g.tx().commit(); g.E().count();";
+                        "schema.propertyKey('name').asText().ifNotExist().create();" +
+                        "schema.vertexLabel('char').useCustomizeNumberId()" +
+                        "      .properties('name').ifNotExist().create();" +
+                        "schema.edgeLabel('next').sourceLabel('char').targetLabel('char')" +
+                        "      .properties('name').ifNotExist().create();" +
+                        "g.addV('char').property(id,1).property('name','A').as('a')" +
+                        " .addV('char').property(id,2).property('name','B').as('b')" +
+                        " .addV('char').property(id,3).property('name','C').as('c')" +
+                        " .addV('char').property(id,4).property('name','D').as('d')" +
+                        " .addV('char').property(id,5).property('name','E').as('e')" +
+                        " .addV('char').property(id,6).property('name','F').as('f')" +
+                        " .addE('next').from('a').to('b').property('name','ab')" +
+                        " .addE('next').from('b').to('c').property('name','bc')" +
+                        " .addE('next').from('b').to('d').property('name','bd')" +
+                        " .addE('next').from('c').to('d').property('name','cd')" +
+                        " .addE('next').from('c').to('e').property('name','ce')" +
+                        " .addE('next').from('d').to('e').property('name','de')" +
+                        " .addE('next').from('e').to('f').property('name','ef')" +
+                        " .addE('next').from('f').to('d').property('name','fd')" +
+                        " .iterate();" +
+                        "g.tx().commit(); g.E().count();";
 
         HugeTask<Object> task = runGremlinJob(script);
         task = scheduler.waitUntilTaskCompleted(task.id(), 10);
@@ -344,14 +346,15 @@ public class TaskCoreTest extends BaseCoreTest {
         task = scheduler.waitUntilTaskCompleted(task.id(), 10);
         Assert.assertEquals(TaskStatus.SUCCESS, task.status());
         String expected = String.format("[{\"labels\":[[],[],[]],\"objects\":[" +
-                "{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"A\"}}," +
-                "{\"id\":\"L1>%s>>L2\",\"label\":\"next\",\"type\":\"edge\",\"outV\":1," +
-                "\"outVLabel\":\"char\",\"inV\":2,\"" +
-                "inVLabel\":\"char\",\"properties\":{\"name\":\"ab\"}}," +
-                "{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"B\"}}" +
-                "]}]", edgeLabelId);
+                                        "{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
+                                        "\"properties\":{\"name\":\"A\"}}," +
+                                        "{\"id\":\"L1>%s>>L2\",\"label\":\"next\"," +
+                                        "\"type\":\"edge\",\"outV\":1," +
+                                        "\"outVLabel\":\"char\",\"inV\":2,\"" +
+                                        "inVLabel\":\"char\",\"properties\":{\"name\":\"ab\"}}," +
+                                        "{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
+                                        "\"properties\":{\"name\":\"B\"}}" +
+                                        "]}]", edgeLabelId);
         Assert.assertEquals(expected, task.result());
 
         script = "g.V(1).out().out().path()";
@@ -359,19 +362,19 @@ public class TaskCoreTest extends BaseCoreTest {
         task = scheduler.waitUntilTaskCompleted(task.id(), 10);
         Assert.assertEquals(TaskStatus.SUCCESS, task.status());
         expected = "[{\"labels\":[[],[],[]],\"objects\":[" +
-                "{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"A\"}}," +
-                "{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"B\"}}," +
-                "{\"id\":3,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"C\"}}]}," +
-                "{\"labels\":[[],[],[]],\"objects\":[" +
-                "{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"A\"}}," +
-                "{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"B\"}}," +
-                "{\"id\":4,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"D\"}}]}]";
+                   "{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"A\"}}," +
+                   "{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"B\"}}," +
+                   "{\"id\":3,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"C\"}}]}," +
+                   "{\"labels\":[[],[],[]],\"objects\":[" +
+                   "{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"A\"}}," +
+                   "{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"B\"}}," +
+                   "{\"id\":4,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"D\"}}]}]";
         Assert.assertEquals(expected, task.result());
 
         script = "g.V(1).outE().inV().tree()";
@@ -379,14 +382,16 @@ public class TaskCoreTest extends BaseCoreTest {
         task = scheduler.waitUntilTaskCompleted(task.id(), 10);
         Assert.assertEquals(TaskStatus.SUCCESS, task.status());
         expected = String.format("[[{\"key\":{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"A\"}}," +
-                "\"value\":[" +
-                "{\"key\":{\"id\":\"L1>%s>>L2\",\"label\":\"next\",\"type\":\"edge\",\"outV\":1," +
-                "\"outVLabel\":\"char\",\"inV\":2,\"inVLabel\":\"char\"," +
-                "\"properties\":{\"name\":\"ab\"}}," +
-                "\"value\":[{\"key\":{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"B\"}},\"value\":[]}]}]}]]",
-                edgeLabelId);
+                                 "\"properties\":{\"name\":\"A\"}}," +
+                                 "\"value\":[" +
+                                 "{\"key\":{\"id\":\"L1>%s>>L2\",\"label\":\"next\"," +
+                                 "\"type\":\"edge\",\"outV\":1," +
+                                 "\"outVLabel\":\"char\",\"inV\":2,\"inVLabel\":\"char\"," +
+                                 "\"properties\":{\"name\":\"ab\"}}," +
+                                 "\"value\":[{\"key\":{\"id\":2,\"label\":\"char\"," +
+                                 "\"type\":\"vertex\"," +
+                                 "\"properties\":{\"name\":\"B\"}},\"value\":[]}]}]}]]",
+                                 edgeLabelId);
         Assert.assertEquals(expected, task.result());
 
         script = "g.V(1).out().out().tree()";
@@ -394,14 +399,14 @@ public class TaskCoreTest extends BaseCoreTest {
         task = scheduler.waitUntilTaskCompleted(task.id(), 10);
         Assert.assertEquals(TaskStatus.SUCCESS, task.status());
         expected = "[[{\"key\":{\"id\":1,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"A\"}}," +
-                "\"value\":[{\"key\":{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
-                "\"properties\":{\"name\":\"B\"}}," +
-                "\"value\":[" +
-                "{\"key\":{\"id\":3,\"label\":\"char\",\"type\":\"vertex\",\"properties\":" +
-                "{\"name\":\"C\"}},\"value\":[]}," +
-                "{\"key\":{\"id\":4,\"label\":\"char\",\"type\":\"vertex\",\"properties\":" +
-                "{\"name\":\"D\"}},\"value\":[]}]}]}]]";
+                   "\"properties\":{\"name\":\"A\"}}," +
+                   "\"value\":[{\"key\":{\"id\":2,\"label\":\"char\",\"type\":\"vertex\"," +
+                   "\"properties\":{\"name\":\"B\"}}," +
+                   "\"value\":[" +
+                   "{\"key\":{\"id\":3,\"label\":\"char\",\"type\":\"vertex\",\"properties\":" +
+                   "{\"name\":\"C\"}},\"value\":[]}," +
+                   "{\"key\":{\"id\":4,\"label\":\"char\",\"type\":\"vertex\",\"properties\":" +
+                   "{\"name\":\"D\"}},\"value\":[]}]}]}]]";
         Assert.assertEquals(expected, task.result());
     }
 
@@ -558,7 +563,7 @@ public class TaskCoreTest extends BaseCoreTest {
         Assert.assertEquals(TaskStatus.CANCELLED, task.status());
         Assert.assertEquals("test-gremlin-job", task.name());
         Assert.assertTrue(task.result(), task.result() == null ||
-                          task.result().endsWith("InterruptedException"));
+                                         task.result().endsWith("InterruptedException"));
 
         // Cancel success task
         HugeTask<Object> task2 = runGremlinJob("1+2");
